===================================================
 ceph-medic -- Find common issues in Ceph clusters
===================================================

``ceph-medic`` is a very simple tool to run against a Ceph cluster to detect
common issues that might prevent correct functionality. It requires
non-interactive SSH access to accounts that can ``sudo`` without a password
prompt.

Full usage documentation can be found at: http://docs.ceph.com/ceph-medic
